@@ -2,7 +2,7 @@
 
 # This file is part of App Launcher
 
-# Copyright © 2018-2021 Ubuntu Budgie Developers
+# Copyright © 2018 Ubuntu Budgie Developers
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,6 +23,6 @@ class FilterHelper():
                     searchText.lower() in app.getName().lower():
                 filteredApps.append(app)
             counter += 1
-        if searchText is "":
+        if searchText == "":
             filteredApps = apps
         return filteredApps
